/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.mediatypes.builtin;

import org.wso2.registry.Artifact;
import org.wso2.registry.RegistryException;
import org.wso2.registry.jdbc.ConnectionFactory;
import org.wso2.registry.jdbc.mediatypes.MediaTypeHandler;
import org.wso2.registry.jdbc.mediatypes.MediaTypeManager;
import org.wso2.usermanager.Realm;

public class SQLQueryMediaTypeHandler extends MediaTypeHandler {

    public SQLQueryMediaTypeHandler(ConnectionFactory connectionFactory,
                             Realm realm,
                             MediaTypeManager mediaTypeManager) {

        super(connectionFactory, realm, mediaTypeManager);
    }

    public Artifact get(String path, Artifact artifact) throws RegistryException {

        Object content = artifact.getContent();
        if (content instanceof byte[]) {
            artifact.setContent(new String((byte[])content));
        }

        return artifact;
    }

    public boolean put(String path, Artifact artifact) throws RegistryException {

        Object content = artifact.getContent();
        if (content instanceof String) {
            String textContent = (String) content;
            artifact.setContent(textContent.getBytes());
        }

        MediaTypeHandler defaultMediaTypeHandler = mediaTypeManager.getDefaultMediaTypeHandler();
        defaultMediaTypeHandler.put(path, artifact);

        return true;
    }

    public boolean delete(String path) throws RegistryException {
        // we are not doing anything special for deleting sql queries
        return false;
    }
}
